libcosmic/cosmic/cctk/sctk/primary_selection/device/trait.PrimarySelectionDeviceHandler.html

16 lines
6.7 KiB
HTML
Raw Normal View History

<!DOCTYPE html><html lang="en"><head><meta charset="utf-8"><meta name="viewport" content="width=device-width, initial-scale=1.0"><meta name="generator" content="rustdoc"><meta name="description" content="API documentation for the Rust `PrimarySelectionDeviceHandler` trait in crate `cosmic`."><title>PrimarySelectionDeviceHandler in cosmic::cctk::sctk::primary_selection::device - Rust</title><script>if(window.location.protocol!=="file:")document.head.insertAdjacentHTML("beforeend","SourceSerif4-Regular-6b053e98.ttf.woff2,FiraSans-Italic-81dc35de.woff2,FiraSans-Regular-0fe48ade.woff2,FiraSans-MediumItalic-ccf7e434.woff2,FiraSans-Medium-e1aa3f0a.woff2,SourceCodePro-Regular-8badfe75.ttf.woff2,SourceCodePro-Semibold-aa29a496.ttf.woff2".split(",").map(f=>`<link rel="preload" as="font" type="font/woff2" crossorigin href="../../../../../static.files/${f}">`).join(""))</script><link rel="stylesheet" href="../../../../../static.files/normalize-9960930a.css"><link rel="stylesheet" href="../../../../../static.files/rustdoc-aa0817cf.css"><meta name="rustdoc-vars" data-root-path="../../../../../" data-static-root-path="../../../../../static.files/" data-current-crate="cosmic" data-themes="" data-resource-suffix="" data-rustdoc-version="1.90.0-nightly (3048886e5 2025-07-30)" data-channel="nightly" data-search-js="search-fa3e91e5.js" data-settings-js="settings-5514c975.js" ><script src="../../../../../static.files/storage-68b7e25d.js"></script><script defer src="sidebar-items.js"></script><script defer src="../../../../../static.files/main-eebb9057.js"></script><noscript><link rel="stylesheet" href="../../../../../static.files/noscript-32bb7600.css"></noscript><link rel="alternate icon" type="image/png" href="../../../../../static.files/favicon-32x32-6580c154.png"><link rel="icon" type="image/svg+xml" href="../../../../../static.files/favicon-044be391.svg"></head><body class="rustdoc trait"><!--[if lte IE 11]><div class="warning">This old browser is unsupported and will most likely display funky things.</div><![endif]--><nav class="mobile-topbar"><button class="sidebar-menu-toggle" title="show sidebar"></button></nav><nav class="sidebar"><div class="sidebar-crate"><h2><a href="../../../../../cosmic/index.html">cosmic</a><span class="version">1.0.0</span></h2></div><div class="sidebar-elems"><section id="rustdoc-toc"><h2 class="location"><a href="#">Primary<wbr>Selection<wbr>Device<wbr>Handler</a></h2><h3><a href="#required-methods">Required Methods</a></h3><ul class="block"><li><a href="#tymethod.selection" title="selection">selection</a></li></ul><h3><a href="#dyn-compatibility">Dyn Compatibility</a></h3><h3><a href="#implementors">Implementors</a></h3></section><div id="rustdoc-modnav"><h2><a href="index.html">In cosmic::<wbr>cctk::<wbr>sctk::<wbr>primary_<wbr>selection::<wbr>device</a></h2></div></div></nav><div class="sidebar-resizer" title="Drag to resize sidebar"></div><main><div class="width-limiter"><rustdoc-search></rustdoc-search><section id="main-content" class="content"><div class="main-heading"><div class="rustdoc-breadcrumbs"><a href="../../../../index.html">cosmic</a>::<wbr><a href="../../../index.html">cctk</a>::<wbr><a href="../../index.html">sctk</a>::<wbr><a href="../index.html">primary_selection</a>::<wbr><a href="index.html">device</a></div><h1>Trait <span class="trait">PrimarySelectionDeviceHandler</span><button id="copy-path" title="Copy item path to clipboard">Copy item path</button></h1><rustdoc-toolbar></rustdoc-toolbar><span class="sub-heading"></span></div><pre class="rust item-decl"><code>pub trait PrimarySelectionDeviceHandler: <a class="trait" href="https://doc.rust-lang.org/nightly/core/marker/trait.Sized.html" title="trait core::marker::Sized">Sized</a> {
// Required method
fn <a href="#tymethod.selection" class="fn">selection</a>(
&amp;mut self,
conn: &amp;<a class="struct" href="../../reexports/client/struct.Connection.html" title="struct cosmic::cctk::sctk::reexports::client::Connection">Connection</a>,
qh: &amp;<a class="struct" href="../../reexports/client/struct.QueueHandle.html" title="struct cosmic::cctk::sctk::reexports::client::QueueHandle">QueueHandle</a>&lt;Self&gt;,
primary_selection_device: &amp;<a class="struct" href="../../reexports/protocols/wp/primary_selection/zv1/client/zwp_primary_selection_device_v1/struct.ZwpPrimarySelectionDeviceV1.html" title="struct cosmic::cctk::sctk::reexports::protocols::wp::primary_selection::zv1::client::zwp_primary_selection_device_v1::ZwpPrimarySelectionDeviceV1">ZwpPrimarySelectionDeviceV1</a>,
);
}</code></pre><span class="item-info"><div class="stab portability">Available on <strong>crate feature <code>wayland</code> and Linux</strong> only.</div></span><h2 id="required-methods" class="section-header">Required Methods<a href="#required-methods" class="anchor"></a></h2><div class="methods"><details class="toggle method-toggle" open><summary><section id="tymethod.selection" class="method"><h4 class="code-header">fn <a href="#tymethod.selection" class="fn">selection</a>(
&amp;mut self,
conn: &amp;<a class="struct" href="../../reexports/client/struct.Connection.html" title="struct cosmic::cctk::sctk::reexports::client::Connection">Connection</a>,
qh: &amp;<a class="struct" href="../../reexports/client/struct.QueueHandle.html" title="struct cosmic::cctk::sctk::reexports::client::QueueHandle">QueueHandle</a>&lt;Self&gt;,
primary_selection_device: &amp;<a class="struct" href="../../reexports/protocols/wp/primary_selection/zv1/client/zwp_primary_selection_device_v1/struct.ZwpPrimarySelectionDeviceV1.html" title="struct cosmic::cctk::sctk::reexports::protocols::wp::primary_selection::zv1::client::zwp_primary_selection_device_v1::ZwpPrimarySelectionDeviceV1">ZwpPrimarySelectionDeviceV1</a>,
)</h4></section></summary><div class="docblock"><p>The new selection is received.</p>
<p>The given primary selection device could be used to identify <a href="struct.PrimarySelectionDevice.html" title="struct cosmic::cctk::sctk::primary_selection::device::PrimarySelectionDevice"><code>PrimarySelectionDevice</code></a>.</p>
</div></details></div><h2 id="dyn-compatibility" class="section-header">Dyn Compatibility<a href="#dyn-compatibility" class="anchor"></a></h2><div class="dyn-compatibility-info"><p>This trait is <b>not</b> <a href="https://doc.rust-lang.org/nightly/reference/items/traits.html#dyn-compatibility">dyn compatible</a>.</p><p><i>In older versions of Rust, dyn compatibility was called "object safety", so this trait is not object safe.</i></p></div><h2 id="implementors" class="section-header">Implementors<a href="#implementors" class="anchor"></a></h2><div id="implementors-list"></div><script src="../../../../../trait.impl/smithay_client_toolkit/primary_selection/device/trait.PrimarySelectionDeviceHandler.js" async></script></section></div></main></body></html>